# AuthoritySpoke

[![CircleCI](https://circleci.com/gh/mscarey/AuthoritySpoke.svg?style=svg)](https://circleci.com/gh/mscarey/AuthoritySpoke) [![Coverage Status](https://coveralls.io/repos/github/mscarey/AuthoritySpoke/badge.svg?branch=master)](https://coveralls.io/github/mscarey/AuthoritySpoke?branch=master)

AuthoritySpoke is a Python library for managing structured data about legal rules.

## Learning about AuthoritySpoke

The best way to familiarize yourself with AuthoritySpoke is through the [Introduction to AuthoritySpoke Jupyter notebook](notebooks/introduction.ipynb).

Use this button to interact with the notebook online through Binder.

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/mscarey/AuthoritySpoke/master)

[Full documentation for AuthoritySpoke](https://authorityspoke.readthedocs.io/en/latest/) is a work in progress.

## Installing AuthoritySpoke

I suggest running AuthoritySpoke in a Pipenv environment. See the [installation instructions for Pipenv](https://docs.pipenv.org/en/latest/install/#installing-pipenv).

Then run

```
$ pipenv install
$ pipenv shell
```

If everything worked, AuthoritySpoke should be available to import in your Python environment.

```
$ python
```

```
import authorityspoke
```

## Contributing to AuthoritySpoke

Contributor documentation is coming soon!

All participants are expected to follow the [code of conduct](code_of_conduct.md). AuthoritySpoke uses the [Contributor Covenant, version 1.4,](https://www.contributor-covenant.org/version/1/4/code-of-conduct.html).

Submitting a pull request or other code contribution to AuthoritySpoke requires acceptance of a [contributor license agreement](contributor_agreement.md). The agreement's provisions are based on the [Apache Software Foundation Individual Contributor License Agreement V2.0](http://www.apache.org/licenses/icla.pdf).
